<template>
  <a-card :bordered="false" :class="'cust-erp-sub-tab'">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator" v-if="mainId">
      <!-- <a-button @click="handleAdd" type="primary" icon="plus" :disabled="!this.mainId">新增</a-button> -->
      <a-button type="primary" icon="download" @click="handleExportXls('仓库服务对象')" v-if="false">导出</a-button>
      <a-upload name="file" :showUploadList="false" :multiple="false" :headers="tokenHeader" :action="importExcelUrl"
        @change="handleImportExcel">
        <a-button type="primary" icon="import" v-if="false">导入</a-button>
      </a-upload>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel"><a-icon type="delete" />删除</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown>
    </div>
    <a-table ref="table" size="middle" bordered rowKey="id" :scroll="{ x: true }" :columns="columns"
      :dataSource="dataSource" :pagination="ipagination" :loading="loading"
      :rowSelection="{ selectedRowKeys: selectedRowKeys, onChange: onSelectChange }" @change="handleTableChange">
      <template slot="htmlSlot" slot-scope="text">
        <div v-html="text"></div>
      </template>
      <template slot="imgSlot" slot-scope="text,record">
        <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
        <img v-else :src="getImgView(text)" :preview="record.id" height="25px" alt=""
          style="max-width:80px;font-size: 12px;font-style: italic;" />
      </template>
      <template slot="fileSlot" slot-scope="text">
        <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
        <a-button v-else :ghost="true" type="primary" icon="download" size="small" @click="downloadFile(text)">
          下载
        </a-button>
      </template>

      <span slot="action" slot-scope="text, record">
        <a href="javascript:;" @click="handleDownload(record)">下载</a>
      </span>
    </a-table>
    <warehouseClient-modal ref="modalForm" @ok="modalFormOk" :mainId="mainId" :enterpriseId="enterpriseId"
      :originTargetKeys="originTargetKeys"></warehouseClient-modal>
    <PdfView ref="pdfview"></PdfView>
  </a-card>
</template>
<style>
.notShow {
  display: none
}
</style>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import WarehouseClientModal from './modules/WarehouseClientModal'
import { getAction, downFile,getFileAccessHttpUrl } from '@/api/manage'
import PdfView from '@views/common/PdfView'
import Tooltip from 'ant-design-vue/es/tooltip'
export default {
  name: "WarehouseClientList",
  mixins: [JeecgListMixin],
  components: { WarehouseClientModal, PdfView, Tooltip },
  props: {
    mainId: {
      type: String,
      default: '',
      required: false
    },
    enterpriseId: {
      type: String,
      default: '',
      required: false
    }
  },
  watch: {
    mainId: {
      immediate: true,
      handler(val) {
        if (!this.mainId) {
          this.clearList()
        } else {
          this.queryParam['calibrationOrderId'] = val;
          this.queryParam['delFlag'] = '0';
          this.isButtonShow = true;
          this.loadData(1);
          this.selectedRowKeys = [];
        }
      }
    }
  },
  data() {
    return {
      description: '检定附件报告',
      disableMixinCreated: true,
      // 表头
      columns: [
        {
          title: '文档编号',
          align: "center",
          customRender: function (t, r, index) {
            return r.upload.id
          }
        },
        {
          title: '文档名称',
          align: "center",
          customRender: function (t, r, index) {
            return r.upload.name
          }
        },

        {
          title: '文档类型',
          align: "center",
          width: 220,
          customRender: function (t, r, index) {
            return r.upload.format
          }
        },
        {
          title: '上传时间',
          align: "center",
          width: 220,
          customRender: function (t, r, index) {
            return r.upload.createTime
          }

        },
        {
          title: '上传者',
          align: "center",
          customRender: function (t, r, index) {
            return r.upload.createBy
          }
        },
        {
          title: '大小',
          align: "center",
          customRender: function (t, r, index) {
            return r.upload.size
          }
        },
        {
          title: '判定结果',
          align: "center",
          customRender: function (t, r, index) {
            return r.upload.em
          }
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: "center",
          fixed: "right",
          width: 200,
          scopedSlots: { customRender: 'action' },
        }
      ],
      url: {
        list: "/sys/uploadRela/listByBusIdAndBusType",
        delete: "/eam/calibrationOrderDetail/delete",
        deleteBatch: "/eam/calibrationOrderDetail/deleteBatch",
        exportXlsUrl: "/eam/calibrationOrderDetail/exportWarehouseClient",
        importUrl: "/eam/calibrationOrderDetail/importWarehouseClient",
        download: '/sys/upload/downloadFile',
      },
      dictOptions: {
      },
      originTargetKeys: []
    }
  },
  computed: {
    importExcelUrl() {
      return `${window._CONFIG['domianURL']}/${this.url.importUrl}/${this.mainId}`;
    }
  },
  methods: {
    handleDownload(record) {
      downFile(this.url.download, { id: record.upload.id }).then((res) => {
        if (!res) {
          this.$message.warning('文件下载失败')
          return
        } else {
          let fileName = record.upload.name;
          if (typeof window.navigator.msSaveBlob !== 'undefined') {
            window.navigator.msSaveBlob(new Blob([res]), fileName);
          } else {
            let url = window.URL.createObjectURL(new Blob([res]));
            let link = document.createElement('a');
            link.style.display = 'none';
            link.href = url;
            link.setAttribute('download', fileName);
            document.body.appendChild(link);
            link.click()
            document.body.removeChild(link) //下载完成移除元素
            window.URL.revokeObjectURL(url) //释放掉blob对象
          }
        }
      })
    },


    view(record) {
      this.$refs.pdfview.showPdf(record.src);
    },
    clearList() {
      this.dataSource = []
      this.selectedRowKeys = []
      this.ipagination.current = 1
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error("请设置url.list属性!")
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      var params = this.getQueryParams();//查询条件
      params.busType = 'calibration_order_photo'
      params.busId = this.mainId
      this.loading = true;
      this.originTargetKeys = [];
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          //update-begin---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
          this.dataSource = res.result.records || res.result;

          for (var i = 0; i < res.result.records.length; i++) {
            let r = res.result.records[i].upload;
            r.src = this.getSrc(res.result.records[i].upload);
            var clientId = res.result.records[i]['clientId']
            this.originTargetKeys.push(clientId)
          }
          if (res.result.total) {
            this.ipagination.total = res.result.total;
          } else {
            this.ipagination.total = 0;
          }
          //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },
    getSrc(record) {
      if (!record.path) {
        return '';
      }
      //本地：local\Minio：minio\阿里云：alioss
      if (record.uploadType == 'local') {
        let ssoLoginFlag = Vue.ls.get("ssoLoginFlag");
        let deployMode = Vue.ls.get("deployMode");

        if (ssoLoginFlag && deployMode == "container") {
          var baseProject = Vue.ls.get("baseProject");

          var hostname = window.location.protocol + "//" + window.location.host;
          var url = hostname + '/' + baseProject + '/sys/common/static';
          return getFileAccessHttpUrl(record.path + record.encodeName, url, window._CONFIG['hyperTextTransfer'])
        } else {
          //根据发布状态修改https 或 http
          return getFileAccessHttpUrl(record.path + record.encodeName, this.url.urlDownload, window._CONFIG['hyperTextTransfer'])
        }

      } else if (record.uploadType == 'alioss') {
        const OSS = require('ali-oss')
        const client = new OSS({
          // region以杭州为例（oss-cn-hangzhou），其他region按实际情况填写。
          region: window._CONFIG['region'],
          accessKeyId: window._CONFIG['accessKeyId'],
          accessKeySecret: window._CONFIG['accessKeySecret'],
          bucket: window._CONFIG['bucket'],
        })
        // object-key表示从OSS下载文件时需要指定包含文件后缀在内的完整路径，例如abc/efg/123.jpg。
        return client.signatureUrl(record.path)
      }
    },
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less'
</style>
